agbrowse docs

Reference

Use live help as the contract for flags and commands.

The docs summarize stable command families. The exact parser surface is the output of agbrowse --help and agbrowse web-ai --help.

Browser commands

start, stop, status, snapshot, click, type, press, tabs, tab-switch, tab-cleanup, console, network, fetch.

Web-AI commands

render, status, send, poll, query, code, code-extract, stop, watch, snapshot, sessions, project-sources, context-dry-run, context-render, doctor, claim-audit.

Help checks

agbrowse --help
agbrowse web-ai --help
agbrowse web-ai code --help
agbrowse web-ai code-extract --help